@@ -9,9 +9,7 @@ use wrangler::cli::{exec, Cli, Command};
 use wrangler::commands;
 use wrangler::installer;
 use wrangler::reporter;
-use wrangler::terminal::message::{Message, StdOut};
-use wrangler::terminal::styles;
-use wrangler::version::background_check_for_updates;
+use wrangler::version::check_for_updates;
 
 use anyhow::Result;
 use structopt::StructOpt;
@@ -35,22 +33,7 @@ fn main() -> Result<()> {
         }
     }
     run()?;
-    if let Ok(latest_version) = background_check_for_updates().try_recv() {
-        let latest_version = styles::highlight(latest_version.to_string());
-        let new_version_available = format!(
-            "A new version of Wrangler ({}) is available!",
-            latest_version
-        );
-        let update_message = "You can learn more about updating here:".to_string();
-        let update_docs_url = styles::url(
-            "https://developers.cloudflare.com/workers/cli-wrangler/install-update#update",
-        );
-
-        StdOut::billboard(&format!(
-            "{}\n{}\n{}",
-            new_version_available, update_message, update_docs_url
-        ));
-    }
+    check_for_updates();
     Ok(())
 }
 
